block_contains_transaction

Function block_contains_transaction 

pub fn block_contains_transaction(
    builder: &CircuitBuilder,
    transaction_hash: [Wire; 4],
    siblings: &[([Wire; 4], Wire)],
    merkle_path_len: Wire,
    block_header: [Wire; 10],
    block_hash: [Wire; 4],
)
Asserts that transaction_hash has a valid merkle path to the merkle root in block_header, and that block_header hashes to block_hash.

Note: This does NOT assert that transaction_hash is actually the hash of a well formed transaction. In particular, transaction_hash might just be an internal (non-leaf) node in the transaction merkle tree, yet this circuit would pass.